GetCompatibleBitmap     PROTO :dword,:dword,:dword,:dword,:dword
GetBitmapDC             PROTO :dword,:dword,:dword,:dword
BlitWindow              PROTO :dword,:dword,:dword,:dword




.CONST
BW_COPY     equ 0
BW_CENTER   equ 1
BW_STRETCH  equ 2
BW_TILE     equ 3

.CODE


;========================================================================
;Title	Creating DC's to paint on
;Author	JimmyClif
;Submitted by:	JimmyClif
;Date added:	2002-02-17 18:11:42
;Date modified:	2002-02-17 18:18:39
;
;This little function is used to create DC for BackBuffers, Images and so on.
;All there is to do is pass 2 dwords which will hold the DC (the one you'll be painting on)
;and the handleDC which both need to be deleted at program exit (with DeleteDC and DeleteObject)
;
;========================================================================
;                           GetCompatibleBitmap
;========================================================================
;  Usage:
;  invoke GetCompatibleDC, ADDR ImageDC, ADDR hImageDC, hwnd, 500, 300
;========================================================================
GetCompatibleBitmap proc AnotherDC:DWORD, HandleOfDC:DWORD, hwnd:DWORD, xLenght:DWORD, yWidth:DWORD
    invoke CreateCompatibleDC,NULL
    mov edx,AnotherDC
    push eax
    mov [edx],eax
    invoke GetDC,hwnd
    push eax
    invoke CreateCompatibleBitmap,eax,xLenght,yWidth
    mov edx,HandleOfDC
    mov ecx,[esp]       ;pop ecx
    mov [esp],eax       ;push eax
    mov [edx],eax
    invoke ReleaseDC,hwnd,ecx
    pop eax             ;HandleOfDC
    pop ecx             ;AnotherDC
    invoke SelectObject,ecx,eax
    ret
GetCompatibleBitmap endp


;========================================================================
;Title	Getting the DC from a Bitmap
;Author	JimmyClif
;Submitted by:	JimmyClif
;Date added:	2002-02-17 18:17:27
;Date modified:	2002-02-17 18:17:27
;
;This is used to create DC's for Bitmaps. Just pass :
;BitmapDC an empty dword - which will receive the DC you'll be working with later on.
;NameOfBitmap - the name of the Bitmap to take into the DC.
;HandleOfBitmap - an empty dword which will receive the handle of the Bitmap.
;Do not forget to DeleteDC and DeleteObject for the created Handle and DC at program exit.
;
;========================================================================
;                           GetBitmapDC
;========================================================================
;  Usage:
;  invoke GetBitmapDC, ADDR BitmapDC, ADDR NameOfBitmap, ADDR hBitmap, hwnd
;========================================================================
GetBitmapDC proc AnotherDC:DWORD, BitmapADDR:DWORD,HandleOfBitmap:DWORD, hwnd:DWORD 
    invoke GetDC,hwnd 
    push eax            ;1 push DC for release later 
    invoke CreateCompatibleDC,eax 
    mov edx,AnotherDC 
    push eax            ;2 push DC for SelectObject 
    mov [edx],eax 
    Invoke LoadImage, hInstance, BitmapADDR, IMAGE_BITMAP, 0, 0, LR_LOADFROMFILE
    ;invoke LoadBitmap,hInstance,BitmapADDR 
    ;.IF eax == NULL
    ;    Invoke MessageBox, hwnd, BitmapADDR, BitmapADDR, MB_OK
    ;.endif
    mov edx,HandleOfBitmap 
    pop ecx                ;2 pop Created DC 
    mov [edx],eax 
    invoke SelectObject,ecx,eax 
    pop eax                ;1 pop DC to release 
    invoke ReleaseDC,hwnd,eax 
ret 
GetBitmapDC endp


;========================================================================
;Title	BlitWindow
;Author	QvasiModo
;Submitted by:	QvasiModo
;Date added:	2003-07-23 19:11:08
;Date modified:	2003-07-23 19:11:08

;Paints a bitmap into a window's client area. You can use four styles:
;BW_COPY Copies the bitmap at the upper left corner.
;BW_CENTER Centers the bitmap in the client area.
;BW_STRETCH Stretches the bitmap to cover the entire client area.
;BW_TILE Tiles the bitmap to cover the entire client area.
;
;========================================================================
;                           BlitWindow
;========================================================================
; Paints a bitmap into a window's client area. You can use four styles:
;========================================================================
BlitWindow proc hwnd,hdc,hbmp,flags
    LOCAL hMemoryDC:HDC
    LOCAL hOldBmp:DWORD
    LOCAL rect:RECT
    LOCAL bitmap:BITMAP

    invoke GetClientRect,hwnd,addr rect
    invoke CreateCompatibleDC,hdc
    mov hMemoryDC,eax
    invoke SelectObject,eax,hbmp
    mov hOldBmp,eax
    invoke GetObject,hbmp,sizeof BITMAP,addr bitmap

    mov ecx,flags
    test ecx,ecx
    jnz @1          ;BW_COPY

    invoke BitBlt,hdc,0,0,bitmap.bmWidth,bitmap.bmHeight,hMemoryDC,0,0,SRCCOPY

@1: loop @2         ;BW_CENTER

    mov eax,rect.right
    sub eax,bitmap.bmWidth
    shr eax,1
    mov edx,rect.bottom
    sub edx,bitmap.bmHeight
    shr edx,1
    invoke BitBlt,hdc,eax,edx,bitmap.bmWidth,bitmap.bmHeight,hMemoryDC,0,0,SRCCOPY

    jmp @F
@2: loop @3         ;BW_STRETCH

    invoke StretchBlt,hdc,0,0,rect.right,rect.bottom,hMemoryDC,0,0,bitmap.bmWidth,bitmap.bmHeight,SRCCOPY

    jmp @F
@3: loop @4         ;BW_TILE

    push esi
    push edi
    xor edi,edi
    .repeat
        xor esi,esi
        .repeat
            invoke BitBlt,hdc,esi,edi,bitmap.bmWidth,bitmap.bmHeight,hMemoryDC,0,0,SRCCOPY
            add esi,bitmap.bmWidth
        .until esi >= rect.right
        add edi,bitmap.bmHeight
    .until edi >= rect.bottom
    pop edi
    pop esi

@4:
@@: invoke SelectObject,hMemoryDC,hOldBmp
    invoke DeleteDC,hMemoryDC
    ret
BlitWindow endp

